from ase.db import connect
from gpaw import GPAW, PW, Davidson
from gpaw.xc.libvdwxc import vdw_beef
from gpaw.utilities.timing import ParallelTimer

db = connect('ZSM22.json')
for row in db.select():
    atoms = row.toatoms()
    #print(atoms)
    #continue
    name = atoms.get_chemical_formula() + '-BEEF-vdW'
    if not name.startswith('HAl'):
        continue
    atoms.calc = GPAW(xc=vdw_beef(), #'BEEF-vdW',
                      mode=PW(600),
                      timer=ParallelTimer(),
                      eigensolver=Davidson(4),
                      parallel=dict(augment_grids=True),
                      txt=name + '.txt',
                      convergence={'eigenstates': 1e-6})
    def stopcalc():
        atoms.calc.scf.converged = True
    atoms.calc.attach(stopcalc, 5)
    atoms.get_potential_energy()
